==> oto-service-api-0.0.1-20221013.064918-6-sources.jar: cn/com/duiba/oto/dto/oto/seller/OtoSellerDTO.java <==
package cn.com.duiba.oto.dto.oto.seller;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

@Data
public class OtoSellerDTO implements Serializable {

    private static final long serialVersionUID = -6283587838740023380L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 销售手机号
     */
    private String phoneNumber;

    /**
     * 销售姓名
     */
    private String sellerName;

    /**
     * 工作台使用权限 0禁用 1启用
     * {@link cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerStatusEnum}
     */
    private Integer sellerStatus;

    /**
     * 呼叫权限,0-禁用,1-启用
     * {@link cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerCallPermissionEnum}
     */
    private Integer callPermission;

    /**
     * 认领新客户&强制分配权限 0禁用 1启用
     * {@link cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerPermissionEnum}
     */
    private Integer assignNewCustPermission;

    /**
     * 认领回收客户权限 0禁用 1启用
     * {@link cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerPermissionEnum}
     */
    private Integer assignRecycleCustPermission;

    /**
     * 角色类型,1-普通销售,2-销售管理员
     * {@link cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerRoleTypeEnum}
     */
    private Integer roleType;

    /**
     * 所属上级销售id
     */
    private Long parentId;

    /**
     * 销售等级,1=A,2=B,3=C
     * @see cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerLevelEnum
     */
    private Integer sellerLevel;

    /**
     * 所属公司id
     * tb_oto_company.id
     */
    private Long sellerCompany;

    /**
     * 工作状态,0-非工作中,1=工作中
     * @see cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerWorkStatusEnum
     */
    private Integer workStatus;

    /**
     * 离职状态，0-未离职，1-已离职
     * @see cn.com.duiba.live.normal.service.api.enums.oto.OtoSellerDimissionStatusEnum
     */
    private Integer dimissionStatus;

    /**
     * 销售所在地区
     */
    private String sellerArea;

    /**
     * 最后登录时间
     */
    private Date lastLoginTime;

    /**
     * 创建时间
     */
    private Date gmtCreate;
    /**
     * 用户ID
     */
    private Long userId;
}

==> oto-service-api-0.2.28-20241209.022239-2-sources.jar: cn/com/duiba/oto/dto/oto/seller/OtoSellerDTO.java <==
package cn.com.duiba.oto.dto.oto.seller;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

@Data
public class OtoSellerDTO implements Serializable {

    private static final long serialVersionUID = -6283587838740023380L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 销售手机号
     */
    private String phoneNumber;

    /**
     * 销售姓名
     */
    private String sellerName;

    /**
     * 销售新老状态 0新销售 1老销售
     * {@link cn.com.duiba.oto.enums.OtoSellerOldEnum}
     */
    private Integer newSeller;

    /**
     * 工作台使用权限 0禁用 1启用
     * {@link cn.com.duiba.oto.enums.OtoSellerStatusEnum}
     */
    private Integer sellerStatus;

    /**
     * 呼叫权限,0-禁用,1-启用
     * {@link cn.com.duiba.oto.enums.OtoSellerCallPermissionEnum}
     */
    private Integer callPermission;

    /**
     * 认领新客户&强制分配权限 0禁用 1启用
     * {@link cn.com.duiba.oto.enums.OtoSellerPermissionEnum}
     */
    private Integer assignNewCustPermission;

    /**
     * 认领回收客户权限 0禁用 1启用
     * {@link cn.com.duiba.oto.enums.OtoSellerPermissionEnum}
     */
    private Integer assignRecycleCustPermission;

    /**
     * 角色类型,1-普通销售,2-销售管理员
     * {@link cn.com.duiba.oto.enums.OtoSellerRoleTypeEnum}
     */
    private Integer roleType;

    /**
     * 所属上级销售id
     */
    private Long parentId;

    /**
     * 销售等级,1=A,2=B,3=C
     * @see cn.com.duiba.oto.enums.OtoSellerLevelEnum
     */
    private Integer sellerLevel;

    /**
     * 所属公司id
     * tb_oto_company.id
     */
    private Long sellerCompany;

    /**
     * 工作状态,0-非工作中,1=工作中
     * @see cn.com.duiba.oto.enums.OtoSellerWorkStatusEnum
     */
    private Integer workStatus;

    /**
     * 离职状态，0-未离职，1-已离职
     * @see cn.com.duiba.oto.enums.OtoSellerDimissionStatusEnum
     */
    private Integer dimissionStatus;

    /**
     * 销售所在地区
     */
    private String sellerArea;

    /**
     * 最后登录时间
     */
    private Date lastLoginTime;

    /**
     * 创建时间
     */
    private Date gmtCreate;
    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 使用第三方类型 1:合力忆捷 2:云客，用‘,’分开'
     *
     * @see cn.com.duiba.oto.enums.cust.call.OtoCustomerCallThirdPartyEnum
     */
    private String thirdParty;
}
